@@ -23,10 +23,10 @@
 
 #include "bitset.h"
 
-extern size_t lbitset_bytes (bitset_bindex);
+size_t lbitset_bytes (bitset_bindex);
 
-extern bitset lbitset_init (bitset, bitset_bindex);
+bitset lbitset_init (bitset, bitset_bindex);
 
-extern void lbitset_release_memory (void);
+void lbitset_release_memory (void);
 
 #endif
