@@ -1,6 +1,7 @@
 /* Functions to support vbitsets.
 
-   Copyright (C) 2002, 2004, 2009-2012 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2009-2015, 2018 Free Software Foundation,
+   Inc.
 
    Contributed by Michael Hayes (m.hayes@elec.canterbury.ac.nz).
 
@@ -22,8 +23,8 @@
 
 #include "bitset.h"
 
-extern size_t vbitset_bytes (bitset_bindex);
+size_t vbitset_bytes (bitset_bindex);
 
-extern bitset vbitset_init (bitset, bitset_bindex);
+bitset vbitset_init (bitset, bitset_bindex);
 
 #endif
