@@ -1,6 +1,7 @@
 /* Keep a unique copy of strings.
 
-   Copyright (C) 2002-2005, 2009-2013 Free Software Foundation, Inc.
+   Copyright (C) 2002-2005, 2009-2015, 2018 Free Software Foundation,
+   Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -55,19 +56,36 @@ uniqstr_new (char const *str)
 }
 
 uniqstr
-uniqstr_vsprintf (char const *format, ...)
+uniqstr_concat (int nargs, ...)
 {
   va_list args;
-  size_t length;
-  va_start (args, format);
-  length = vsnprintf (NULL, 0, format, args);
+
+  va_start (args, nargs);
+  size_t reslen = 0;
+  for (int i = 0; i < nargs; i++)
+    reslen += strlen (va_arg (args, char const *));
   va_end (args);
 
-  char res[length + 1];
-  va_start (args, format);
-  vsprintf (res, format, args);
+  char *str = xmalloc (reslen + 1);
+  char *p = str;
+
+  va_start (args, nargs);
+  for (int i = 0; i < nargs; i++)
+    {
+      char const *arg = va_arg (args, char const *);
+      size_t arglen = strlen (arg);
+      memcpy (p, arg, arglen);
+      p += arglen;
+    }
   va_end (args);
-  return uniqstr_new (res);
+
+  *p = '\0';
+  uniqstr res = hash_insert (uniqstrs_table, str);
+  if (!res)
+    xalloc_die ();
+  if (res != str)
+    free (str);
+  return res;
 }
 
 /*------------------------------.
@@ -77,10 +95,11 @@ uniqstr_vsprintf (char const *format, ...)
 void
 uniqstr_assert (char const *str)
 {
-  if (!hash_lookup (uniqstrs_table, str))
+  uniqstr s = hash_lookup (uniqstrs_table, str);
+  if (!s || s != str)
     {
       error (0, 0,
-	     "not a uniqstr: %s", quotearg (str));
+             "not a uniqstr: %s", quotearg (str));
       abort ();
     }
 }
@@ -103,7 +122,17 @@ uniqstr_print_processor (void *ustr, void *null ATTRIBUTE_UNUSED)
   return uniqstr_print (ustr);
 }
 
-
+
+int
+uniqstr_cmp (uniqstr l, uniqstr r)
+{
+  return (l == r ? 0
+          : !l ? -1
+          : !r ? +1
+          : strcmp (l, r));
+}
+
+
 /*-----------------------.
 | A uniqstr hash table.  |
 `-----------------------*/
@@ -111,7 +140,7 @@ uniqstr_print_processor (void *ustr, void *null ATTRIBUTE_UNUSED)
 static bool
 hash_compare_uniqstr (void const *m1, void const *m2)
 {
-  return strcmp (m1, m2) == 0;
+  return STREQ (m1, m2);
 }
 
 static size_t
@@ -120,6 +149,7 @@ hash_uniqstr (void const *m, size_t tablesize)
   return hash_string (m, tablesize);
 }
 
+
 /*----------------------------.
 | Create the uniqstrs table.  |
 `----------------------------*/
@@ -128,10 +158,10 @@ void
 uniqstrs_new (void)
 {
   uniqstrs_table = hash_initialize (HT_INITIAL_CAPACITY,
-				    NULL,
-				    hash_uniqstr,
-				    hash_compare_uniqstr,
-				    free);
+                                    NULL,
+                                    hash_uniqstr,
+                                    hash_compare_uniqstr,
+                                    free);
 }
 
 
